@@ -25,15 +25,15 @@ function(myxlab, mytitle, n, s, mdp, mmd, msmd, mytype, H0, ...) {
 
   usr <- par("usr")
   rect(usr[1], usr[3], usr[2], usr[4],
-       col=getOption("bg.fill"), border=getOption("bg.stroke"))
+       col=getOption("panel.fill"), border=getOption("panel.color"))
 
-  abline(v=axTicks(1), col=getOption("grid.x.stroke"),
+  abline(v=axTicks(1), col=getOption("grid.x.color"),
          lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
-  abline(h=axTicks(2), col=getOption("grid.y.stroke"),
+  abline(h=axTicks(2), col=getOption("grid.y.color"),
          lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
 
   .axes(NULL, NULL, axTicks(1), axTicks(2),
-        par("usr")[1], par("usr")[3], cex.axis=.8, col.axis="gray30")
+        par("usr")[1], par("usr")[3], col.axis="gray30")
 
   main.lab <- NULL
   sub.lab <- NULL
@@ -42,8 +42,8 @@ function(myxlab, mytitle, n, s, mdp, mmd, msmd, mytype, H0, ...) {
   .axlabs(x.label, y.label, main.lab, sub.lab, max.lbl.y=3, cex.lab=0.85) 
 
   col.fill <- getOption("pt.fill")
-  col.stroke <- getOption("pt.stroke")
-  points(x.values, y.values, pch=21, type="l", col=col.stroke,
+  col.color <- getOption("pt.color")
+  points(x.values, y.values, pch=21, type="l", col=col.color,
          bg=col.fill, cex=0.8)
 
   abline(h=0, lwd=.5, col="gray50")
